# Towing test data of the Kyushu University kite system

Date: 10 December 2019

Location: Shiroshi, Saga, Japan (33°08'49.2"N 130°11'20.1"E).



## Introduction
Kites can be used to harvest wind energy at higher altitudes while using only a fraction of the material required for conventional wind turbines. In this work, we present a data set acquired by tow tests of a kite system developed in Kyushu University.  The aforementioned kite system is designed for 7 kW traction power and comprises an inflatable wing with a suspended kite control unit that is tethered to a towing vehicle to produce a controlled relative flow environment. A measurement unit is attached to the kite for data acquisition. The tensile force in the tether was measured using a tension meter. A detailed description of the test setup is given in Ref [[1]](#Rushdi2020).

## Description of the tests

The tests were performed on a day with only little wind to avoid a perturbation of the relative airflow generated by the towing. Under these circumstances, the apparent wind speed at the kite and the truck speed are nearly identical.

The experimental work comprises seven tests summarized in the following table, for different combinations of towing speed, kite maneuver and control line length (CLL).


| Test no. 	| Towing Speed (km/h)     |        Flight Mode        		| CLL (m) 	|       File Name       	 |
|:--------:	|:----------------------:	|:---------------------------:	|:-------:	|:----------------------:	 |
|     1    	|        30 ~ 40        	|       Steady flight       		|   13.8  	| Test 1-40-13,8-steady    |
|     2    	|        30 ~ 40        	| Figure-of-eight maneuvers   	|   13.8  	|  Test 2-40-13,8-Fig8  	 |
|     3    	|        40 ~ 50        	|       Steady flight       		|   13.8  	| Test 3-50-13,8-steady    |
|     4    	|        40 ~ 50        	| Figure-of-eight maneuvers   	|   13.8  	|  Test 4-50-13,8-Fig8  	 |
|     5    	|        30 ~ 40        	|       Steady flight       		|   13.6  	| Test 5-40-13,6-steady    |
|     6    	|        30 ~ 40        	|       Steady flight       		|   13.4  	| Test 6-40-13,4-steady    |
|     7    	|        40 ~ 50        	|       Steady flight       		|   13.6  	| Test 7-50-13,6-steady    |



The objective of these tests was to quantify the effect of these parameters on the tether force. For tests 1–4, the truck followed a continuous towing-path A-B-A-B-A on the runway (A is the start point on the runway, B is the other end of the runway), performing two loops. Each time the end points A or B were reached, the truck performed a U-turn at a reduced speed of 20 km/h. For tests 5–7, only a single loop was performed. During towing, the kite was either operated in figure-of-eight flight maneuvers, or kept in a steady flight state by maintaining a constant position with respect to the truck.

The tests were performed on a small air field for unmanned aerial vehicles at Shiroshi, Saga, Japan, with a runway of 750 m.

## Content of the data set

The acquired data is provided in csv-format and includes the time histories of the variables in the following table.


| ID 	|  Variable  	|                Description               		|  Unit  	|
|:--:	|:----------:	|:-----------------------------------------:	|:------:	|
| 01 	|    time    	|        Time since start recording          	|    s   	|
| 02 	|    long    	|              Kite longitude              		| degree 	|
| 03 	|     lat    	|               Kite latitude              		| degree 	|
| 04 	|     dt     	|               Sampling time              		|    s   	|
| 05 	|      H     	|                Kite height               		|    m   	|
| 06 	|    Roll    	|              Kite roll angle             		| degree 	|
| 07 	|    Pitch   	|             Kite pitch angle             		| degree 	|
| 08 	|     Yaw    	|              Kite yaw angle              		| degree 	|
| 09 	|      S     	|   Number of satellites connected to GPS   	|    -   	|
| 10 	| truckSpeed  |               Towing Speed               	  |  km/h 	|
| 11 	|  truck_lat  |              Truck latitude            	  	| degree 	|
| 12 	| truck_long  |              Truck longitude              	| degree 	|
| 13 	|   Tension   | Tensile force measured in the power line   	|    N   	|


The body-fixed reference frame of the kite, in which we measured roll, pitch and yaw, is similar to the conventional aircraft body axes.
- x-axis: Along the chord line, from the trailing edge towards the leading edge.
- y-axis: Perpendicular to the x-axis and towards the right-wing tip according to the measurement unit (MU), which is mounted on the leading edge.
- z-axis: Perpendicular to the x-y plan according to the right-hand rule.

## Other information

- The collected data was used for a sensitivity analysis and to predict the tensile force using multivariate machine learning (ML) algorithms [[1]](#Rushdi2020).



## References

<a name="Rushdi2020">[1]</a> Mostafa A. Rushdi, Ahmed A. Rushdi, Tarek N. Deif, Amr M. Halawa, Shigeo Yoshida and Roland Schmehl: "**Power Prediction of Airborne Wind Energy Systems Using Multivariate Machine Learning**", Energies, 13(9), p. 2367, 2020. [https://doi.org/10.3390/en13092367](https://doi.org/10.3390/en13092367)

## Authors

Mostafa A. Rushdi, Email: rushdimostafa@riam.kyushu-u.ac.jp \
Roland Schmehl, Email: r.schmehl@tudelft.nl

## License

This data set is licensed under the [![License: CC BY 4.0](https://img.shields.io/badge/License-CC%20BY%204.0-lightgrey.svg)](https://creativecommons.org/licenses/by/4.0/)

## Acknowledgments

We acknowledge the help of

- **Tarek N. Dief**, Postdoctoral researcher @ RIAM, Kyushu University, Japan.
- **Daichi Fujimoto**, Masters student (M-2), @ IGSES, ESST, Kyushu University, Japan.
- **Kosuke Sawano**, Masters student (M-2), @ IGSES, ESST, Kyushu University, Japan.

for the setup and execution of the towing tests.
